pub struct InventoryAccess {
inventory: Shared<PlayerInventory>,
hand: InteractionHand,
}Expand description
Access to the player’s inventory.
This handle does not hold the inventory lock by itself. Use the closure methods to keep lock scopes short and avoid carrying an inventory guard through block behavior, world mutation, or menu opening.
Fields
inventory: Shared<PlayerInventory>hand: InteractionHandImplementations
Sourceimpl InventoryAccess
impl InventoryAccess
Sourcepub const fn new(
inventory: Shared<PlayerInventory>,
hand: InteractionHand,
) -> Self
pub const fn new( inventory: Shared<PlayerInventory>, hand: InteractionHand, ) -> Self
Creates a new InventoryAccess instance.
Sourcepub fn with_item<R>(&self, f: impl FnOnce(&mut ItemStack) -> R) -> R
pub fn with_item<R>(&self, f: impl FnOnce(&mut ItemStack) -> R) -> R
Runs f with mutable access to the item in the player’s hand.
Sourcepub fn with_inventory<R>(&self, f: impl FnOnce(&mut PlayerInventory) -> R) -> R
pub fn with_inventory<R>(&self, f: impl FnOnce(&mut PlayerInventory) -> R) -> R
Runs f with mutable access to the player’s inventory.
Sourcepub fn with_guard<R>(&self, f: impl FnOnce(&mut ContainerLockGuard) -> R) -> R
pub fn with_guard<R>(&self, f: impl FnOnce(&mut ContainerLockGuard) -> R) -> R
Runs f with a container guard containing the player’s inventory.
Prefer Self::with_item or Self::with_inventory unless an operation
must interoperate with APIs that require ContainerLockGuard.